@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ca">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ El(s) dispositiu(s) wifi potser ja estan desbloquejats. </translation>
         <translation>No es pot descarregar </translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
