@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="cs">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ Zařízení WiFi by už mohlo být odblokováno(y).</translation>
         <translation>Nelze uvolnit</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
