@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="el">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ WiFi device(s) might already be unlocked.</source>
         <translation>Δεν ήταν δυνατή η εκφόρτωση </translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
