@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es_ES">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ Es posible que los dispositivos WiFi ya estén desbloqueados.</translation>
         <translation>No se pudo descargar</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
