@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="fr">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>MainWindow</name>
     <message>
@@ -11,7 +9,7 @@
     <message>
         <location filename="../mainwindow.ui" line="86"/>
         <source>About...</source>
-        <translation>À propos...</translation>
+        <translation>À propos…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="108"/>
@@ -570,4 +568,4 @@ Il se peut que les périphériques Wi-Fi soient déjà déverrouillés.</transla
         <translation>Déchargement impossible</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
