@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="he_IL">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he_IL">
 <context>
     <name>MainWindow</name>
     <message>
@@ -557,7 +555,7 @@ WiFi device(s) might already be unlocked.</source>
     <message>
         <location filename="../main.cpp" line="79"/>
         <source>You must run this program with admin access.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="624"/>
@@ -570,4 +568,4 @@ WiFi device(s) might already be unlocked.</source>
         <translation>לא ניתן לפרוק</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
