@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ Il dispositivo/i WiFi  potrebbe essere già sbloccato/i.</translation>
         <translation>Impossibile scaricare</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
