@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ Urządzenia Wi-Fi mogą być już odblokowane.</translation>
         <translation>Nie można odinstalować</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
