@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pt">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ O(s) dispositivo(s) Wi-Fi podem já estar desbloqueados.</translation>
         <translation>Não foi possível descarregar</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
