@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ru">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
 <context>
     <name>MainWindow</name>
     <message>
@@ -557,7 +555,7 @@ Wi-Fi устройство(а) может быть уже разблокиров
     <message>
         <location filename="../main.cpp" line="79"/>
         <source>You must run this program with admin access.</source>
-        <translation type="unfinished"></translation>
+        <translation>Вы должны запустить эту программу с правами администратора.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="624"/>
@@ -570,4 +568,4 @@ Wi-Fi устройство(а) может быть уже разблокиров
         <translation>Невозможно выгрузить</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
