@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ru_RU">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru_RU">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ Wi-Fi устройство(а) может быть уже разблокиров
         <translation>Невозможно выгрузить</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
