@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="tr">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
 <context>
     <name>MainWindow</name>
     <message>
@@ -570,4 +568,4 @@ Kablosuz cihaz(lar)ının kilidi zaten açık olabilir.</translation>
         <translation>Kaldırılamadı</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
